| Title: | Access to Public Who Targets Me API |
|---|---|
| Description: | Access to Public Who Targets Me API. |
| Authors: | Fabio Votta [aut, cre] |
| Maintainer: | Fabio Votta <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 0.0.0.9000 |
| Built: | 2026-05-12 09:13:57 UTC |
| Source: | https://github.com/favstats/wtmapi |
The goal of wtm_get is to provide access to the public data API of Who Targets Me.
wtm_get( endpoint, country = NULL, party = NULL, limit = NULL, skip = NULL, selects = NULL, sort_by = NULL, sort_dir = 1, values_in_var = NULL, values_nin_var = NULL, lt = NULL, lte = NULL, gt = NULL, gte = NULL, ne = NULL, or = NULL, ..., raw = F )wtm_get( endpoint, country = NULL, party = NULL, limit = NULL, skip = NULL, selects = NULL, sort_by = NULL, sort_dir = 1, values_in_var = NULL, values_nin_var = NULL, lt = NULL, lte = NULL, gt = NULL, gte = NULL, ne = NULL, or = NULL, ..., raw = F )
endpoint |
the API endpoint you want to retrieve. currently supports: |
country |
which country to retrieve data from (ISO2). Examples: |
party |
which party to retrieve data from. Examples: |
limit |
will return only the number of results you specify |
skip |
will skip the specified number of results |
selects |
allows to pick which fields to include in the result, chr or vector of chrs |
sort_by |
will sort based on the variable you provide (chr) |
sort_dir |
sort direction ( |
values_in_var |
find all records where the property does ( |
values_nin_var |
find all records where the property does not ( |
lt |
find all records where the value is less ( |
lte |
find all records where the value is less and equal ( |
gt |
find all records where the value is more ( |
gte |
find all records where the value is more and equal ( |
ne |
find all records that do not equal the given property value. Input is a list: |
or |
find all records that match any of the given criteria. Specify the params as chr (vector) that should be combined with an |
... |
additional arguments you can pass to test for equality. Example = |
raw |
whether to return the raw |
# retrieve all advertiser targeting methods in the use # that have a greater or equal value of `bct = 1`. wtm_get(endpoint = "candidates-targeting-methods", country = "US", gte = list(bct = 1)) # retrieve all advertiser targeting methods in the use # that have a greater or equal value of `bct = 1` OR # `custom_audiences_lookalike = 20`. wtm_get(endpoint = "candidates-targeting-methods", country = "US", gte = list(bct = 1), value_in_var = list(custom_audiences_lookalike = 20), or = c("gte", "value_in_var"))# retrieve all advertiser targeting methods in the use # that have a greater or equal value of `bct = 1`. wtm_get(endpoint = "candidates-targeting-methods", country = "US", gte = list(bct = 1)) # retrieve all advertiser targeting methods in the use # that have a greater or equal value of `bct = 1` OR # `custom_audiences_lookalike = 20`. wtm_get(endpoint = "candidates-targeting-methods", country = "US", gte = list(bct = 1), value_in_var = list(custom_audiences_lookalike = 20), or = c("gte", "value_in_var"))